@@ -56,6 +56,7 @@ struct _EphyEmbedShellClass
 };
 
 EphyEmbedShell    *ephy_embed_shell_get_default                (void);
+const char        *ephy_embed_shell_get_guid                   (EphyEmbedShell   *shell);
 WebKitWebContext  *ephy_embed_shell_get_web_context            (EphyEmbedShell   *shell);
 EphyHistoryService
                   *ephy_embed_shell_get_global_history_service (EphyEmbedShell   *shell);
@@ -73,10 +74,6 @@ gboolean           ephy_embed_shell_launch_handler             (EphyEmbedShell
                                                                 GFile            *file,
                                                                 const char       *mime_type,
                                                                 guint32           user_time);
-void               ephy_embed_shell_add_app_related_uri        (EphyEmbedShell   *shell,
-                                                                const char       *uri);
-gboolean           ephy_embed_shell_uri_looks_related_to_app   (EphyEmbedShell   *shell,
-                                                                const char       *uri);
 void               ephy_embed_shell_clear_cache                (EphyEmbedShell   *shell);
 void               ephy_embed_shell_set_thumbnail_path         (EphyEmbedShell   *shell,
                                                                 const char       *url,
