@@ -38,7 +38,6 @@ typedef enum {
   SET_URL_TITLE,
   SET_URL_ZOOM_LEVEL,
   SET_URL_HIDDEN,
-  SET_URL_THUMBNAIL_TIME,
   ADD_VISIT,
   ADD_VISITS,
   DELETE_URLS,
@@ -103,7 +102,7 @@ ephy_history_service_set_property (GObject *object, guint property_id, const GVa
   switch (property_id) {
     case PROP_HISTORY_FILENAME:
       g_free (self->history_filename);
-      self->history_filename = g_strdup (g_value_get_string (value));
+      self->history_filename = g_value_dup_string (value);
       break;
     case PROP_READ_ONLY:
       self->read_only = g_value_get_boolean (value);
@@ -942,49 +941,6 @@ ephy_history_service_set_url_hidden (EphyHistoryService    *self,
   ephy_history_service_send_message (self, message);
 }
 
-static gboolean
-ephy_history_service_execute_set_url_thumbnail_time (EphyHistoryService *self,
-                                                     EphyHistoryURL     *url,
-                                                     gpointer           *result)
-{
-  gint64 thumbnail_time;
-
-  if (self->read_only)
-    return FALSE;
-
-  thumbnail_time = url->thumbnail_time;
-
-  if (ephy_history_service_get_url_row (self, NULL, url) == NULL)
-    return FALSE;
-  else {
-    url->thumbnail_time = thumbnail_time;
-    ephy_history_service_update_url_row (self, url);
-    return TRUE;
-  }
-}
-
-void
-ephy_history_service_set_url_thumbnail_time (EphyHistoryService    *self,
-                                             const char            *orig_url,
-                                             gint64                 thumbnail_time,
-                                             GCancellable          *cancellable,
-                                             EphyHistoryJobCallback callback,
-                                             gpointer               user_data)
-{
-  EphyHistoryURL *url;
-  EphyHistoryServiceMessage *message;
-
-  g_assert (EPHY_IS_HISTORY_SERVICE (self));
-  g_assert (orig_url != NULL);
-
-  url = ephy_history_url_new (orig_url, NULL, 0, 0, 0);
-  url->thumbnail_time = thumbnail_time;
-  message = ephy_history_service_message_new (self, SET_URL_THUMBNAIL_TIME,
-                                              url, (GDestroyNotify)ephy_history_url_free,
-                                              cancellable, callback, user_data);
-  ephy_history_service_send_message (self, message);
-}
-
 static gboolean
 ephy_history_service_execute_get_url (EphyHistoryService *self,
                                       const gchar        *orig_url,
@@ -1207,7 +1163,6 @@ static EphyHistoryServiceMethod methods[] = {
   (EphyHistoryServiceMethod)ephy_history_service_execute_set_url_title,
   (EphyHistoryServiceMethod)ephy_history_service_execute_set_url_zoom_level,
   (EphyHistoryServiceMethod)ephy_history_service_execute_set_url_hidden,
-  (EphyHistoryServiceMethod)ephy_history_service_execute_set_url_thumbnail_time,
   (EphyHistoryServiceMethod)ephy_history_service_execute_add_visit,
   (EphyHistoryServiceMethod)ephy_history_service_execute_add_visits,
   (EphyHistoryServiceMethod)ephy_history_service_execute_delete_urls,
