@@ -219,14 +219,20 @@ button_press_cb (EphyNotebook   *notebook,
 
   tab_clicked = find_tab_num_at_pos (notebook, event->x_root, event->y_root);
 
+  if (event->type == GDK_BUTTON_PRESS && event->button == GDK_BUTTON_MIDDLE) {
+    GtkWidget *tab = gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), tab_clicked);
+    g_signal_emit (notebook, signals[TAB_CLOSE_REQUEST], 0, tab);
+    return GDK_EVENT_STOP;
+  }
+
   if (event->type == GDK_BUTTON_PRESS &&
-      event->button == 3 &&
+      event->button == GDK_BUTTON_SECONDARY &&
       (event->state & gtk_accelerator_get_default_mod_mask ()) == 0) {
     if (tab_clicked == -1) {
       /* Consume event so that we don't pop up the context
        * menu when the mouse is not over a tab label.
        */
-      return TRUE;
+      return GDK_EVENT_STOP;
     }
 
     /* Switch to the page where the mouse is over, but don't consume the
@@ -234,7 +240,7 @@ button_press_cb (EphyNotebook   *notebook,
     gtk_notebook_set_current_page (GTK_NOTEBOOK (notebook), tab_clicked);
   }
 
-  return FALSE;
+  return GDK_EVENT_PROPAGATE;
 }
 
 static void
@@ -338,10 +344,12 @@ static void
 update_tabs_visibility (EphyNotebook *nb,
                         gboolean      before_inserting)
 {
+  EphyEmbedShellMode mode;
   gboolean show_tabs = FALSE;
   guint num;
   EphyPrefsUITabsBarVisibilityPolicy policy;
 
+  mode = ephy_embed_shell_get_mode (EPHY_EMBED_SHELL (ephy_shell_get_default ()));
   num = gtk_notebook_get_n_pages (GTK_NOTEBOOK (nb));
 
   if (before_inserting)
@@ -350,8 +358,9 @@ update_tabs_visibility (EphyNotebook *nb,
   policy = g_settings_get_enum (EPHY_SETTINGS_UI,
                                 EPHY_PREFS_UI_TABS_BAR_VISIBILITY_POLICY);
 
-  if (((policy == EPHY_PREFS_UI_TABS_BAR_VISIBILITY_POLICY_MORE_THAN_ONE && num > 1) ||
-       policy == EPHY_PREFS_UI_TABS_BAR_VISIBILITY_POLICY_ALWAYS))
+  if (mode != EPHY_EMBED_SHELL_MODE_APPLICATION &&
+      ((policy == EPHY_PREFS_UI_TABS_BAR_VISIBILITY_POLICY_MORE_THAN_ONE && num > 1) ||
+        policy == EPHY_PREFS_UI_TABS_BAR_VISIBILITY_POLICY_ALWAYS))
     show_tabs = TRUE;
 
   /* Only show the tabs when the "tabs-allowed" property is TRUE. */
